#include "./webpage.h"

#include "resources/config.h"

#include <QDesktopServices>
#ifdef REPOINDEX_USE_WEBENGINE
# include <QWebEngineSettings>
# include <QWebEngineView>
#else
# include <QWebSettings>
# include <QWebView>
# include <QWebFrame>
#endif

namespace RepoIndex {

WebPage::WebPage(REPOINDEX_WEB_VIEW *view) :
    REPOINDEX_WEB_PAGE(view),
    m_view(view)
{
#ifdef REPOINDEX_USE_WEBENGINE
    settings()->setAttribute(QWebEngineSettings::JavascriptCanOpenWindows, true);
#else
    settings()->setAttribute(QWebSettings::JavascriptCanOpenWindows, true);
#endif
    if(!m_view) {
        // delegate to external browser if no view is assigned
#ifdef REPOINDEX_USE_WEBENGINE
        connect(this, &WebPage::urlChanged, this, &WebPage::delegateToExternalBrowser);
#else
        connect(this->mainFrame(), &QWebFrame::urlChanged, this, &WebPage::delegateToExternalBrowser);
#endif
        m_view = new REPOINDEX_WEB_VIEW;
        m_view->setPage(this);
    }
}

REPOINDEX_WEB_PAGE *WebPage::createWindow(REPOINDEX_WEB_PAGE::WebWindowType type)
{
    Q_UNUSED(type)
    return new WebPage;
}

void WebPage::delegateToExternalBrowser(const QUrl &url)
{
    openUrlExternal(url);
    // this page and the associated view are useless
    m_view->deleteLater();
    deleteLater();
}

void WebPage::openUrlExternal(const QUrl &url)
{
    QDesktopServices::openUrl(url);
}

}
